@@ -176,7 +176,6 @@ void BlackBoardWidget::erase()
 
 QString BlackBoardWidget::imagePath()
 {
-    return KStandardDirs::locateLocal("data", "plasma-desktop-datastorage/blackboard-" + QString::number(m_parentApplet->id()) + ".png"); 
+    return KStandardDirs::locateLocal("data", QLatin1String("plasma-desktop-datastorage/blackboard-") + QString::number(m_parentApplet->id()) + QLatin1String(".png")); 
 }
 
-#include "blackboardwidget.moc"
